pub struct InterleavedComplexRopeConfig {
pub batch: usize,
pub seq_len: usize,
pub query_heads: usize,
pub key_heads: usize,
pub head_dim: usize,
}Expand description
Interleaved complex-frequency RoPE config for Q/K tensors.
Adjacent dimensions are treated as real/imaginary pairs and multiplied by a precomputed complex frequency table laid out as [seq_len, head_dim].
Fields
batch: usizeseq_len: usizequery_heads: usizekey_heads: usizehead_dim: usizeTrait Implementations
Sourceimpl Clone for InterleavedComplexRopeConfig
impl Clone for InterleavedComplexRopeConfig
Sourcefn clone(&self) -> InterleavedComplexRopeConfig
fn clone(&self) -> InterleavedComplexRopeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for InterleavedComplexRopeConfig
Sourceimpl Debug for InterleavedComplexRopeConfig
impl Debug for InterleavedComplexRopeConfig
impl Eq for InterleavedComplexRopeConfig
Sourceimpl PartialEq for InterleavedComplexRopeConfig
impl PartialEq for InterleavedComplexRopeConfig
Sourcefn eq(&self, other: &InterleavedComplexRopeConfig) -> bool
fn eq(&self, other: &InterleavedComplexRopeConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InterleavedComplexRopeConfig