pub struct MultiaxisRopeConfig {
pub batch: usize,
pub seq_len: usize,
pub query_heads: usize,
pub key_heads: usize,
pub head_dim: usize,
pub section_t: usize,
pub section_h: usize,
pub section_w: usize,
}Expand description
Three-axis half-split RoPE config for Q/K tensors.
The cosine and sine tables are split into temporal, height, and width sections. Each section rotates dimensions from the first half of the head with the corresponding dimensions in the second half.
Fields
batch: usizeseq_len: usizequery_heads: usizekey_heads: usizehead_dim: usizesection_t: usizesection_h: usizesection_w: usizeTrait Implementations
Sourceimpl Clone for MultiaxisRopeConfig
impl Clone for MultiaxisRopeConfig
Sourcefn clone(&self) -> MultiaxisRopeConfig
fn clone(&self) -> MultiaxisRopeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MultiaxisRopeConfig
Sourceimpl Debug for MultiaxisRopeConfig
impl Debug for MultiaxisRopeConfig
impl Eq for MultiaxisRopeConfig
Sourceimpl PartialEq for MultiaxisRopeConfig
impl PartialEq for MultiaxisRopeConfig
Sourcefn eq(&self, other: &MultiaxisRopeConfig) -> bool
fn eq(&self, other: &MultiaxisRopeConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MultiaxisRopeConfig